pub struct BgpRibEntry<P: Prefix> {
pub route: BgpRoute<P>,
pub from_type: BgpSessionType,
pub from_id: RouterId,
pub to_id: Option<RouterId>,
pub igp_cost: Option<NotNan<LinkWeight>>,
pub weight: u32,
}Expand description
BGP RIB Table entry
Fields
route: BgpRoute<P>the actual bgp route
from_type: BgpSessionTypethe type of session, from which the route was learned
from_id: RouterIdthe client from which the route was learned
to_id: Option<RouterId>the client to which the route is distributed (only in RibOut)
igp_cost: Option<NotNan<LinkWeight>>the igp cost to the next_hop
weight: u32Local weight of that route, which is the most preferred metric of the entire route.
Implementations
Sourceimpl<P: Prefix> BgpRibEntry<P>
impl<P: Prefix> BgpRibEntry<P>
Sourcepub fn best_route(routes: impl IntoIterator<Item = Self>) -> Option<Self>
pub fn best_route(routes: impl IntoIterator<Item = Self>) -> Option<Self>
Select the best route according to RFC 4271. The algorithm first finds the best routes up to the MED step, then removes those routes that have a lower MED than others (learned from the same peer), and then gets the best route according to all steps after MED.