ConfigExpr

Enum ConfigExpr 

pub enum ConfigExpr<P: Prefix> {
    IgpLinkWeight {
        source: RouterId,
        target: RouterId,
        weight: LinkWeight,
    },
    OspfArea {
        source: RouterId,
        target: RouterId,
        area: OspfArea,
    },
    BgpSession {
        source: RouterId,
        target: RouterId,
        target_is_client: bool,
    },
    BgpRouteMap {
        router: RouterId,
        neighbor: RouterId,
        direction: RouteMapDirection,
        map: RouteMap<P>,
    },
    StaticRoute {
        router: RouterId,
        prefix: P,
        target: StaticRoute,
    },
    LoadBalancing {
        router: RouterId,
    },
    AdvertiseRoute {
        router: RouterId,
        prefix: P,
        as_path: Vec<ASN>,
        med: Option<u32>,
        community: BTreeSet<Community>,
    },
}
Single configuration expression

The expression sets a specific thing in the network.

Variants



IgpLinkWeight

Sets the link weight of a single link (directional) TODO make sure that the weight is strictly smaller than infinity.

Fields

source: RouterId

Source router for link

target: RouterId

Target router for link

weight: LinkWeight

Link weight for IGP



OspfArea

Set the OSPF area of a single link (bidirectional)

Fields

source: RouterId

Source router for link

target: RouterId

Target router for link

area: OspfArea

Area to set the link to



BgpSession

Create a BGP session

Fields

source: RouterId

Source router for Session

target: RouterId

Target router for Session

target_is_client: bool

Whether the target is a route reflector client of the source



BgpRouteMap

Set the BGP Route Map

Fields

router: RouterId

Router to configure the route map

neighbor: RouterId

Neighbor for which to setup the session

direction: RouteMapDirection

Direction (incoming or outgoing)

map: RouteMap<P>

Route Map



StaticRoute

Set a static route

Fields

router: RouterId

On which router set the static route

prefix: P

For which prefix to set the static route

target: StaticRoute

To which neighbor to forward packets to.



LoadBalancing

Enable or disable load balancing

Fields

router: RouterId

Router where to enable the load balancing



AdvertiseRoute

Advertise (originate) a route for a prefix (network)

Fields

router: RouterId

The router that advertises (originates) the route

prefix: P

The prefix (network) to advertise

as_path: Vec<ASN>

The AS path to advertise. Note, that the router will still prepend its own AS when advertising to external neighbors.

med: Option<u32>

The MED value that should be advertised.

community: BTreeSet<Community>

The community value to advertise. Note, that private communities are removed when advertised on eBGP sessions (except those of the receiving AS).

Implementations

Source

impl<P: Prefix> ConfigExpr<P>

pub fn key(&self) -> ConfigExprKey<P>

Returns the key of the config expression. The idea behind the key is that the ConfigExpr cannot be hashed and used as a key for a HashMap. But ConfigExprKey implements Hash, and can therefore be used as a key.

pub fn routers(&self) -> Vec<RouterId>

Returns the router IDs on which the configuration is applied and have to be changed.