pub struct ConfigPatch<P: Prefix> {
pub modifiers: Vec<ConfigModifier<P>>,
}Expand description
Config Patch
A series of ConfigModifiers which can be applied on a Config to get a new Config. The
series is an ordered list, and the modifiers are applied in the order they were added.
Fields
modifiers: Vec<ConfigModifier<P>>List of all modifiers, in the order in which they are applied.
Implementations
Sourceimpl<P: Prefix> ConfigPatch<P>
impl<P: Prefix> ConfigPatch<P>
Sourcepub fn add(&mut self, modifier: ConfigModifier<P>)
pub fn add(&mut self, modifier: ConfigModifier<P>)
Add a new modifier to the patch