MaybePec

Enum MaybePec 

pub enum MaybePec<T> {
    Single(T),
    Pec(Ipv4Net, Vec<T>),
}
Available on crate feature export only.
A datastructure that contains a single value if it corresponds to a single network, or a vector ov values if it corresponds to a prefix equivalence class.

Variants



Single(T)

A single value



Pec(Ipv4Net, Vec<T>)

A vector of alues that correspond to a previx equivalence class

Implementations

Source

impl<T> MaybePec<T>

pub fn first(&self) -> &T

Get the first element in the structure. For Self::Single, this simply returns a reference to the value. For Self::Pec, this returns the reference to the first value. This function panics if the PEC was registered without any associated prefix.

pub fn to_vec(self) -> Vec<T>

Get a vector containing all elements. If self is a single value, then this function returns a vector containing a single value. Otherwise, it will return a vector containing multiple values.

pub fn unwrap_single(self) -> T

Expect that the prefix is a single value, and return it. If the prefix belongs to a prefix equivalence class, this function panics.

pub fn single(self) -> Option<T>

Get the single value or None.

pub fn single_or(self) -> Result<T, ExportError>

Get the single value, or return ExportError::UnexpectedPec.

pub fn single_or_err<E>(self, err: E) -> Result<T, E>

Get the single value, or return Err(err).

pub fn single_or_else<E, F: FnOnce(Vec<T>) -> E>(self, err: F) -> Result<T, E>

Get the single value, or return Error(err(v)), where v is the vector of elements contained within self.

pub fn map<R, F: FnMut(T) -> R>(self, f: F) -> MaybePec<R>

Apply a function to every element, returning a MaybePec with the mapped values.

pub fn iter(&self) -> MaybePecIter<'_, T>

Iterate over all values stored in self as references.

pub fn sample_random_n<R: Rng>(&self, rng: &mut R, n: usize) -> Vec<&T>
where T: Ord,

Available on crate feature rand only.

Get random samples from the prefix equivalence class. If n is smaller or equal to the size of the equivalence class, then simply return all elements. Otherwise, return the first, the last, and some random elements in between.

pub fn sample_uniform_n(&self, n: usize) -> Vec<&T>
where T: Ord,

Get n samples from the prefix equivalence class that are equally spaced. This function may panic if n < 2. If n == 2, then return the smallest and largest element.