NetworkFormatterSequence

Trait NetworkFormatterSequence 

pub trait NetworkFormatterSequence<'n, P, Q, Ospf>
where P: Prefix, Ospf: OspfImpl,
{ // Required methods fn fmt_set(self, net: &'n Network<P, Q, Ospf>) -> String; fn fmt_set_multiline( self, net: &'n Network<P, Q, Ospf>, indent: usize, ) -> String; fn fmt_list(self, net: &'n Network<P, Q, Ospf>) -> String; fn fmt_list_multiline( self, net: &'n Network<P, Q, Ospf>, indent: usize, ) -> String; fn fmt_path(self, net: &'n Network<P, Q, Ospf>) -> String; }
Formatting a sequence as a set, list, or a path.

Required Methods

fn fmt_set(self, net: &'n Network<P, Q, Ospf>) -> String

Format the iterator as a set, e.g., {a, b, c}.

fn fmt_set_multiline( self, net: &'n Network<P, Q, Ospf>, indent: usize, ) -> String

Format the iterator as a set over multiple lines.

fn fmt_list(self, net: &'n Network<P, Q, Ospf>) -> String

Format the iterator as a list, e.g., [a, b, c].

fn fmt_list_multiline( self, net: &'n Network<P, Q, Ospf>, indent: usize, ) -> String

Format the iterator as a milti-line list.

fn fmt_path(self, net: &'n Network<P, Q, Ospf>) -> String

Format the iterator as a path, e.g., a -> b -> c.

Implementors

Source

impl<'n, P, Q, Ospf, I, T> NetworkFormatterSequence<'n, P, Q, Ospf> for I
where P: Prefix, Ospf: OspfImpl, I: IntoIterator<Item = T>, T: NetworkFormatter<'n, P, Q, Ospf>,