OspfDomain

Struct OspfDomain 

pub struct OspfDomain<Ospf = GlobalOspfCoordinator> { /* private fields */ }
The OSPF network for each domain separately. A domain is all routers that belong to the same AS.

Implementations

Source

impl<Ospf> OspfDomain<Ospf>
where Ospf: OspfCoordinator,

pub fn has_edge(&self, a: RouterId, b: RouterId) -> bool

Return true if there exists a link from a (must be part of this AS) to b.

pub fn indices(&self) -> DomainIndices<'_>

Iterate over all router indices in that domain

pub fn graph(&self) -> StableGraph<(), (LinkWeight, OspfArea), Directed, u32>

Generate a graph for only the given domain.

pub fn get_weight(&self, a: RouterId, b: RouterId) -> LinkWeight

Return the OSPF weight of a link (or LinkWeight::INFINITY if the link does not exist).

pub fn get_area(&self, a: RouterId, b: RouterId) -> Option<OspfArea>

Return the OSPF area of a link.

pub fn is_reachable<P: Prefix>( &self, a: RouterId, b: RouterId, routers: &BTreeMap<RouterId, Router<P, Ospf::Process>>, ) -> bool

Returns true if a can reach b, and vice-versa. a must be in this domain, while b can be in another domain.

pub fn coordinator(&self) -> &Ospf

Get a reference to the OSPF coordinator struct

pub fn internal_edges(&self) -> InternalEdges<'_>

Get an iterator over all internal edges. Each link will appear twice, once in each direction.

pub fn external_edges(&self) -> ExternalEdges<'_>

Get an iterator over all external edges (edges that connect to a different AS). Each link will appear once, from the internal router to the external network.

pub fn edges(&self) -> Edges<'_>

Get an iterator over all edges in the network. The iterator will yield first all internal edges twice (once in both directions), and then yield all external edges once (from the internal router to the external network). External edges connect this AS to another one.