ConvergenceRecording

Struct ConvergenceRecording 

pub struct ConvergenceRecording { /* private fields */ }
Record of an entire convergence process that captures the history of each change in the forwarding state of the network. This is a record that allows the state to be moved forwards or backwards in time. The recording can be changed on a per-prefix level.

Implementations

Source

impl ConvergenceRecording

pub fn new( initial_fw_state: ForwardingState<SinglePrefix>, trace: ConvergenceTrace, ) -> Self

Create a Recording from a trace and an initial forwarding state

pub fn state(&mut self) -> &mut ForwardingState<SinglePrefix>

Get a reference to the current forwarding state

pub fn trace(&self) -> &ConvergenceTrace

Get a reference of the convergence trace.

pub fn as_trace(self) -> ConvergenceTrace

Transform the recording into a trace.

pub fn step( &mut self, ) -> Option<(&[FwDelta], Option<f64>, &mut ForwardingState<SinglePrefix>)>

Perform a single step for an individual prefix. If the forwarding state is already in the final state for the specifiied prefix, then this function will return None. Otherwise, it will return a slice containing all deltas that were applied during this function call, the network’s convergence time when the change took effect (if applicable), and a mutable reference to the new ForwardingState.

pub fn back( &mut self, ) -> Option<(&[FwDelta], Option<f64>, &mut ForwardingState<SinglePrefix>)>

Undo a single step for an individual prefix. If the forwarding state is already in the initial state for the specifiied prefix, then this function will return None. Otherwise, it will return a slice containing all deltas that were applied in reverse direction during this function call, the network’s convergence time when the change took effect (if applicable), and a mutable reference to the new ForwardingState.

pub fn pos(&self) -> usize

Get the position of the recording for the given prefix.

pub fn len(&self) -> usize

Get the length of the recording for the given prefix

pub fn is_empty(&self) -> bool

Check if the recording is empty for the given prefix

pub fn into_initial_fw_state(self) -> ForwardingState<SinglePrefix>

Reverts to and releases the initial ForwardingState held by self, while consuming self. This function will also drop any timing information.