SinglePrefixMap

Struct SinglePrefixMap 

pub struct SinglePrefixMap<T>(pub Option<T>);
A mapping of the single prefix to a value. This essentially is a boolean value with a different interface.

Tuple Fields

0: Option<T>

Implementations

Source

impl<T> SinglePrefixMap<T>

pub fn len(&self) -> usize

Return the length of the prefix map, i.e., 1 if there is a value stored for the single prefix, and 0 otheriwse.

pub fn is_empty(&self) -> bool

Return wether the prefix map is empty, i.e., wether there is a value stored for the single preifx.