pub enum ConfigExpr<P: Prefix> {
IgpLinkWeight {
source: RouterId,
target: RouterId,
weight: LinkWeight,
},
OspfArea {
source: RouterId,
target: RouterId,
area: OspfArea,
},
BgpSession {
source: RouterId,
target: RouterId,
target_is_client: bool,
},
BgpRouteMap {
router: RouterId,
neighbor: RouterId,
direction: RouteMapDirection,
map: RouteMap<P>,
},
StaticRoute {
router: RouterId,
prefix: P,
target: StaticRoute,
},
LoadBalancing {
router: RouterId,
},
AdvertiseRoute {
router: RouterId,
prefix: P,
as_path: Vec<ASN>,
med: Option<u32>,
community: BTreeSet<Community>,
},
}Expand description
Single configuration expression
The expression sets a specific thing in the network.
Variants
IgpLinkWeight
Sets the link weight of a single link (directional) TODO make sure that the weight is strictly smaller than infinity.
Fields

weight: LinkWeightLink weight for IGP
OspfArea
Set the OSPF area of a single link (bidirectional)
Fields
BgpSession
Create a BGP session
Fields
BgpRouteMap
Set the BGP Route Map
Fields

direction: RouteMapDirectionDirection (incoming or outgoing)
StaticRoute
Set a static route
Fields

prefix: PFor which prefix to set the static route

target: StaticRouteTo which neighbor to forward packets to.
LoadBalancing
Enable or disable load balancing
AdvertiseRoute
Advertise (originate) a route for a prefix (network)
Implementations
Sourceimpl<P: Prefix> ConfigExpr<P>
impl<P: Prefix> ConfigExpr<P>
Sourcepub fn key(&self) -> ConfigExprKey<P>
pub fn key(&self) -> ConfigExprKey<P>
Returns the key of the config expression. The idea behind the key is that the ConfigExpr
cannot be hashed and used as a key for a HashMap. But ConfigExprKey implements Hash,
and can therefore be used as a key.