pub trait NetworkFormatterSequence<'n, P, Q, Ospf>{
// Required methods
fn fmt_set(self, net: &'n Network<P, Q, Ospf>) -> String;
fn fmt_set_multiline(
self,
net: &'n Network<P, Q, Ospf>,
indent: usize,
) -> String;
fn fmt_list(self, net: &'n Network<P, Q, Ospf>) -> String;
fn fmt_list_multiline(
self,
net: &'n Network<P, Q, Ospf>,
indent: usize,
) -> String;
fn fmt_path(self, net: &'n Network<P, Q, Ospf>) -> String;
}Expand description
Formatting a sequence as a set, list, or a path.
Required Methods
Sourcefn fmt_set(self, net: &'n Network<P, Q, Ospf>) -> String
fn fmt_set(self, net: &'n Network<P, Q, Ospf>) -> String
Format the iterator as a set, e.g., {a, b, c}.
Sourcefn fmt_set_multiline(
self,
net: &'n Network<P, Q, Ospf>,
indent: usize,
) -> String
fn fmt_set_multiline( self, net: &'n Network<P, Q, Ospf>, indent: usize, ) -> String
Format the iterator as a set over multiple lines.
Sourcefn fmt_list(self, net: &'n Network<P, Q, Ospf>) -> String
fn fmt_list(self, net: &'n Network<P, Q, Ospf>) -> String
Format the iterator as a list, e.g., [a, b, c].
Sourcefn fmt_list_multiline(
self,
net: &'n Network<P, Q, Ospf>,
indent: usize,
) -> String
fn fmt_list_multiline( self, net: &'n Network<P, Q, Ospf>, indent: usize, ) -> String
Format the iterator as a milti-line list.