pub struct Router<P: Prefix, Ospf = GlobalOspfProcess> {
pub ospf: Ospf,
pub sr: SrProcess<P>,
pub bgp: BgpProcess<P>,
/* private fields */
}Expand description
Bgp Router
Fields
ospf: OspfThe IGP routing process
sr: SrProcess<P>The Static Routing Process
bgp: BgpProcess<P>The BGP routing process
Implementations
Sourceimpl<P: Prefix, Ospf: OspfProcess> Router<P, Ospf>
impl<P: Prefix, Ospf: OspfProcess> Router<P, Ospf>
Sourcepub unsafe fn trigger_event<T: Default>(
&mut self,
event: Event<P, T>,
) -> Result<(StepUpdate<P>, Vec<Event<P, T>>), DeviceError>
pub unsafe fn trigger_event<T: Default>( &mut self, event: Event<P, T>, ) -> Result<(StepUpdate<P>, Vec<Event<P, T>>), DeviceError>
Manually trigger the given event, returning the result of that event. No new events will be enqueued automatically.
Safety
The network (that this router is in) will be in an inconsistent state. Make sure to deal with that properly.
Sourcepub fn get_fib(&self) -> P::Map<Vec<RouterId>>
pub fn get_fib(&self) -> P::Map<Vec<RouterId>>
Get the forwarding table of the router. The forwarding table is a mapping from each prefix to a next-hop.
TODO: Make this function work with longest prefix map!
Sourcepub fn get_next_hop(&self, prefix: P) -> Vec<RouterId> ⓘ
pub fn get_next_hop(&self, prefix: P) -> Vec<RouterId> ⓘ
Get the IGP next hop for a prefix. Prefixes are matched using longest prefix match.
TODO make this function return a slice