pub struct SinglePrefixMap<T>(pub Option<T>);Expand description
A mapping of the single prefix to a value. This essentially is a boolean value with a different interface.
Tuple Fields
0: Option<T>Implementations
Sourceimpl<T> SinglePrefixMap<T>
impl<T> SinglePrefixMap<T>